# Bootstrap-Flask

![PyPI - License](https://img.shields.io/pypi/l/bootstrap-flask)
[![Current version on PyPI](https://img.shields.io/pypi/v/bootstrap-flask)](https://pypi.org/project/bootstrap-flask/)
[![Build Status](https://travis-ci.org/greyli/bootstrap-flask.svg?branch=master)](https://travis-ci.org/greyli/bootstrap-flask)
[![Coverage Status](https://coveralls.io/repos/github/greyli/bootstrap-flask/badge.svg?branch=master)](https://coveralls.io/github/greyli/bootstrap-flask?branch=master)

Bootstrap 4 helper for Flask/Jinja2.

If you come from Flask-Bootstrap, check out [this tutorial](https://bootstrap-flask.readthedocs.io/en/stable/migrate.html) on how to migrate to this extension.

## Links

* [Documentation](https://bootstrap-flask.readthedocs.io)
* [Example Application](https://github.com/greyli/bootstrap-flask/tree/master/examples)
* [PyPI Releases](https://pypi.org/project/Bootstrap-Flask/)

## License

This project is licensed under the MIT License (see the
`LICENSE` file for details).

Some macros were part of [Flask-Bootstrap](https://github.com/mbr/flask-bootstrap) and were modified under the terms of its BSD License.
